pub struct PlayerProxy { /* private fields */ }Implementations
Sourceimpl PlayerProxy
impl PlayerProxy
Sourcepub fn take_event_stream(&self) -> PlayerEventStream
pub fn take_event_stream(&self) -> PlayerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn play(
&self,
payload: PlayerPlayRequest,
) -> QueryResponseFut<PlayerPlayResult, FDomainResourceDialect>
pub fn play( &self, payload: PlayerPlayRequest, ) -> QueryResponseFut<PlayerPlayResult, FDomainResourceDialect>
Read audio data from a socket in WAV format and play it to a destination.
Returns when all bytes have been read from the socket.