pub struct RecordCancelerProxy { /* private fields */ }Implementations
Sourceimpl RecordCancelerProxy
impl RecordCancelerProxy
Sourcepub fn new(channel: Channel) -> Self
pub fn new(channel: Channel) -> Self
Create a new Proxy for fuchsia.audio.controller/RecordCanceler.
Sourcepub fn take_event_stream(&self) -> RecordCancelerEventStream
pub fn take_event_stream(&self) -> RecordCancelerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn cancel(
&self,
) -> QueryResponseFut<RecordCancelerCancelResult, FDomainResourceDialect>
pub fn cancel( &self, ) -> QueryResponseFut<RecordCancelerCancelResult, FDomainResourceDialect>
Stop recording and writing data on the output socket.